@@ -7,9 +7,9 @@ use common::{SiemMessage, SiemComponentStateStorage, SiemComponentCapabilities};
 use std::boxed::Box;
 pub mod mitre;
 pub mod alert;
-pub mod actuator;
 pub mod metrics;
 pub mod task;
+pub mod use_case;
 use dataset::{SiemDataset};
 use std::collections::BTreeMap;
 use std::sync::{Arc, Mutex};
